@@ -383,7 +383,13 @@ def sequence_with_interval(start_val: int|float, end_val: int|float, interval:in
     if (end_val - start_val)*interval<0:
         raise ValueError(f"Wrong signs; the sequence starts from {start_val} to {end_val}, with an interval of {interval}.")
 
-    return np.linspace(start_val, end_val, np.floor((end_val-start_val)/interval)+1)
+    if isinstance(start_val, int):
+        start_val=float(start_val)
+    if isinstance(end_val, int):
+        end_val=float(end_val)
+    if isinstance(interval, int):
+        interval=float(interval)
+    return np.linspace(start_val, end_val, np.floor((end_val-start_val)/interval).astype(int)+1)
 
 def grid_with_sequences(*sequences):
     for seq in sequences:
